pub struct CompilationOptions {
pub canonicalize_constraints: bool,
}Expand description
Circuit compilation & proving options.
Fields
canonicalize_constraints: boolConverts all constraints to canonical form using Constraint::canonicalize.
When disabled, proving errors out rather than attempting canonicalization if there are negative exponents.
Canonicalization is carried out inside CircuitBuilder::build.
WARNING: canonicalized constraints may be more permissive than their original form because a negative exponent requires the variable to be different from zero. Starkom does not allow proving with negative exponents, so enable this flag only if your circuit is correctly constrained even when those variables are zero.